#
# spec file for package keepassx
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           keepassx
Version:        2.0.2
Release:        8.8
Summary:        Cross Platform Password Manager
License:        GPL-2.0 and LGPL-2.1 and LGPL-3.0+
Group:          Productivity/Security
Url:            https://www.keepassx.org/
Source0:        https://www.keepassx.org/releases/%{version}/keepassx-%{version}.tar.gz
Source1:        https://www.keepassx.org/releases/%{version}/keepassx-%{version}.tar.gz.sig
Source2:        %{name}.keyring
# PATCH-FIX-UPSTREAM keepassx-fix-undefined-libraries.patch
# https://www.keepassx.org/dev/issues/389
Patch0:         keepassx-fix-undefined-libraries.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libXtst-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libqt4-devel >= 4.6
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
Requires:       hicolor-icon-theme
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A free/open-source password manager or safe which helps you to
manage your passwords in a secure way. You can put all your passwords in one
database, which is locked with one master key or a key-disk. So you only have
to remember one single master password or insert the key-disk to unlock the
whole database. The databases are encrypted using the best and most secure
encryption algorithms currently known (AES and Twofish).

%prep
%setup -q
%patch0 -p1

%build
export CFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC"
%cmake \
  -DWITH_CXX11=ON
make %{?_smp_mflags}

%install
%cmake_install
%suse_update_desktop_file %{name} X-SuSE-DesktopUtility

%fdupes -s %{buildroot}/%{_prefix}

%check
make %{?_smp_mflags} -C build test

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc COPYING LICENSE*
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/keepassx.desktop
%{_libdir}/%{name}/
%{_datadir}/icons/hicolor
%{_datadir}/mime/packages/keepassx.xml

%changelog
* Sun Mar 20 2016 mpluskal@suse.com
- Add gpg signature
- Use proper post/postun macros for desktop files and icones
* Mon Feb 15 2016 joop.boonen@opensuse.org
- option -DWITH_LTO isn't available anymore
* Thu Feb 11 2016 mpluskal@suse.com
- Use cmake macros
- Add patch for https://www.keepassx.org/dev/issues/389
  * keepassx-fix-undefined-libraries.patch
* Wed Feb 10 2016 joop.boonen@opensuse.org
- Update to version 2.0.2
  * Fix regression in database writer that caused it to strip certain special
  characters (characters from Unicode plane > 0).
  * Fix bug in repair function that caused it to strip non-ASCII characters
  * Flush temporary file before opening attachment. [#390]
  * Disable password generator when showing entry in history mode. [#422]
  * Strip invalid XML chars when writing databases. [#392]
  * Add repair function to fix databases with invalid XML chars. [#392]
  * Display custom icons scaled. [#322]
  * Allow opening databases that have no password and keyfile. [#391]
  * Fix crash when importing .kdb files with invalid icon ids. [#425]
  * Update translations.
* Mon Jan 18 2016 dimstar@opensuse.org
- Re-enable test suite that was accidentally disabled earlier
  (boo#959078).
* Mon Dec  7 2015 ecsos@opensuse.org
- Update to version 2.0
  * Improve UI of the search edit.
  * Clear clipboard when locking databases. [#342]
  * Enable Ctrl+M shortcut to minimize the window on all platforms.
    [#329]
  * Show a better message when trying to open an old database
    format. [#338]
  * Fix global auto-type behavior with some window managers.
  * Show global auto-type window on the active desktop. [#359]
  * Disable systray on OS X. [#326]
  * Restore main window when clicking on the OS X docker icon.
    [#326]
* Wed Nov  4 2015 michael@stroeder.com
- Update to version 2.0-beta2:
  * Fix crash when locking with search UI open [#309]
  * Fix file locking on Mac OS X [#327]
  * Set default extension when saving a database [#79, #308]
* Mon Jul 20 2015 jacobwinski@gmail.com
- Update build requirements to reflect upstream.
* Mon Jul 20 2015 jacobwinski@gmail.com
- Update to version 2.0-beta1:
  * Remember entry column sizes.
  * Add translations.
  * Support opening attachments directly.
  * Support cmd:// URLs.
  * Protect opened databases with a file lock.
  * Export to csv files.
  * Add optional tray icon.
  * Allow setting the default auto-type sequence for groups.
  * Make the kdbx parser more lenient.
  * Remove –password command line option.
  * Lots of bugfixes.
- Drop keepassx-noselftest.patch: merged upstream.
- Drop keepassx-ppc64le.patch: fixed upstream.
- Drop KeyFileHandling.patch: fixed upstream.
* Mon Aug 25 2014 piny@gmx.com
- KeyFileHandling.patch:
  Process "--keyfile" option correct with following behaviour:
  * Invoking
    keepassx --keyfile kf_02.key db_02.kdbx
    now results in immediate opening of database db_02.kdbx
    if kf_02.key contains the correct key!
  * This also works if the name of the key file is changed, e.g.
    keepassx --keyfile kf_02b.key db_02.kdbx
  * This also works if as per config file additional databases e.g.
    db_01.kdbx and db_03.kdbx are being opened - each of these databases
    displays its own password/keyfile dialog, accordingly.
  * This behaviour can be used to invoke keepassx by autostart
    with a key extracted from kwallet and w/o exposing the key on the
    process list as command line argument
* Mon Aug 25 2014 meissner@suse.com
- keepassx-noselftest.patch: do not run internal selftest as it requires
  libgcrypt checksums which we not always have.
* Fri Aug  1 2014 dvlaeev@suse.com
- Add keepassx-ppc64le.patch: Set correct endianess for ppc64le.
* Thu Apr 17 2014 tchvatal@suse.com
- Update to version 2.0-alpha6:
  * Add option to lock databases after user inactivity [#62]
  * Add compatibility with libgcrypt 1.6 [#129]
  * Display passwords in monospace font [#51]
  * Use an icon for the button that shows/masks passwords [#38]
  * Add an option to show passwords by default [#93]
  * Improve password generator design [#122]
  * On Linux link .kdbx files with KeePassX
  * Remember window size [#154]
  * Disallow global auto-typing when the database is locked
- Drop keepassx-gcrypt-1.6.patch: fixed upstream
* Fri Feb  7 2014 dimstar@opensuse.org
- Update to version 2.0-alpha5:
  + Support copying entries and groups using drag’n'drop [#74].
  + Open last used databases on startup [#36].
  + Made the kdbx file parser more robust.
  + Only edit entries on doubleclick (not single) or with enter
    key.
  + Allow removing multiple entries.
  + Added option to minimize window when copying data to
    clipboard.
  + Save password generator settings.
  + Fixed auto-type producing wrong chars in some keyboard
    configurations [#116].
  + Added some more actions to the toolbar.
- Drop keepassx-2.0-alpha4-fix_lib64.patch: fixed upstream.
- Add keepassx-gcrypt-1.6.patch: Fix build with libgcrypt 1.6.0.
* Fri Dec  6 2013 dimstar@opensuse.org
- Also package LICENSE* files.
* Sun Mar 31 2013 devel.openSUSE.org@gmail.com
- Remove application name from summary
- Add %%fdupes macro to spec
* Sat Mar 30 2013 devel.openSUSE.org@gmail.com
- Update to 2.0.alpha4:
  * Add random password generator [#52]
  * Merge the 'Description' tab into the 'Entry' tab [#59]
  * Fix crash when deleting history items [#56]
  * Fix crash on Mac OS X Mountain Lion during startup [#50]
  * Improved KeePassX application icon [#58]
* Tue Mar  5 2013 idonmez@suse.com
- Implement %%check
- Fix plugin path for 64bit
* Tue Mar  5 2013 idonmez@suse.com
- Cleanup spec file (we only build for SLE/openSUSE)
- Fix version tag
* Mon Mar  4 2013 asn@cryptomilk.org
- Update to 2.0-alpha3
  * Auto-Type on Linux / X11
  * Database locking
  * Fix database corruption when changing key transformation rounds [#34]
  * Verify header data of kdbx files
  * Add menu entry to open URLs in the browser
  * Add menu entry to copy an entry attribute to clipboard
  * Import kdb (KeePass 1) files [#2]
  * Display history items [#23]
  * Implement history item limits [#16]
  * Group and entry icons can be set [#22]
  * Add keyboard shortcuts
  * Search in databases [#24]
  * Sortable entry view
  * Support building Mac OS X bundles
* Thu Jun 28 2012 asn@cryptomilk.org
- Fix build on Factory.
* Tue Mar 30 2010 anschneider@exsuse.de
- Fixed build.
* Sun Mar  7 2010 sniperbeamer_pkg@fobos.de
- Updated to 0.4.3
* Wed Sep 16 2009 sniperbeamer_pkg@fobos.de
- Updated to 0.4.1
* Thu Mar 26 2009 sniperbeamer_pkg@fobos.de
- Updated to 0.4.0
* Sun Nov  9 2008 sniperbeamer_pkg@fobos.de
- Updated to 0.3.4
* Mon Aug 11 2008 sniperbeamer_pkg@fobos.de
- Updated to 0.3.3
* Sun Jul 20 2008 sniperbeamer_pkg@fobos.de
- Updated to 0.3.2
* Tue Apr  1 2008 anschneider@suse.de
- Support Fedora builds
* Tue Apr  1 2008 anschneider@suse.de
- Updated to 0.3.1
  * made key/password dialog more user friendly
  * added option for automatic database locking on inactivity
  * native file dialogs are used again under MacOS X and Windows
  * program accepts Qt command line switches like “-style” again
  * parameter “-cfg” now accepts relative paths
  * fixed invalid entries in .desktop file
  * fixed potential compilation problem in AES implementation
  * fixed crash when re-arranging groups
  * fixed size problems of some dialogs
  * files are not longer truncated when saving fails
  * improved seeding of the random number generator
* Tue Aug  7 2007 anschneider@suse.de
- Updated to current 0.2.3 svn version
* Fri Jun  8 2007 anschneider@suse.de
- Updated to current 0.2.3 svn version
- Fix AppDir detection
* Fri Jun  8 2007 anschneider@suse.de
- inital build
